km3pipe.dataclasses.Track
=========================

.. currentmodule:: km3pipe.dataclasses

.. autoclass:: Track

   
   .. automethod:: __init__

   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Track.bjorkeny
      ~Track.dir
      ~Track.energy
      ~Track.id
      ~Track.interaction_channel
      ~Track.is_cc
      ~Track.length
      ~Track.pos
      ~Track.time
      ~Track.type
   
   